@@ -12,6 +12,5 @@ from collections import OrderedDict
 
 from .fields import TenantForeignKey, TenantOneToOneField
 from .models import TenantManager, TenantModel
-from .thread import ThreadLocals
-from .utils import (get_current_user, get_model_by_db_table,
+from .utils import (get_model_by_db_table,
                     get_current_tenant, set_current_tenant)
